package com.xinelu.manage.mapper.nursestationitem;


import com.xinelu.manage.domain.nursestationitem.NurseStationItem;
import com.xinelu.manage.dto.nursestationitem.NurseStationItemImportDTO;
import com.xinelu.manage.vo.nursestationitem.NurseStationItemInfoDetailsVO;
import com.xinelu.manage.vo.nursestationitem.NurseStationItemVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 护理站护理项目Mapper接口
 *
 * @author ljh
 * @date 2022-09-02
 */
public interface NurseStationItemMapper {
    /**
     * 查询护理站护理项目
     *
     * @param id 护理站护理项目主键
     * @return 护理站护理项目
     */
    NurseStationItemVO selectNurseStationItemById(Long id);

    /**
     * 查询护理站护理项目列表
     *
     * @param nurseStationItem 护理站护理项目
     * @return 护理站护理项目集合
     */
    List<NurseStationItemVO> selectNurseStationItemList(NurseStationItem nurseStationItem);


    /**
     * 查询所有护理项目信息列表
     *
     * @return 护理站护理项目集合
     */
    List<NurseStationItemImportDTO> selectItemInfoList(@Param("nurseStationIdList") List<String> nurseStationIdList);


    /**
     * 新增护理站护理项目
     *
     * @param nurseStationItem 护理站护理项目
     * @return 结果
     */
    int insertNurseStationItem(NurseStationItem nurseStationItem);

    /**
     * 修改护理站护理项目
     *
     * @param nurseStationItem 护理站护理项目
     * @return 结果
     */
    int updateNurseStationItem(NurseStationItem nurseStationItem);

    /**
     * 删除护理站护理项目
     *
     * @param id 护理站护理项目主键
     * @return 结果
     */
    int deleteNurseStationItemById(Long id);

    /**
     * 批量删除护理站护理项目
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteNurseStationItemByIds(Long[] ids);

    /**
     * 查询护理站护理项目
     *
     * @param nurseStationItemIdsList 护理站护理项目主键
     * @return 护理站护理项目
     */
    List<NurseStationItem> getNurseStationItemByIds(@Param("nurseStationItemIdsList") List<Long> nurseStationItemIdsList);

    /**
     * 查询护理站护理项目
     *
     * @param id 护理站护理项目主键
     * @return 护理站护理项目
     */
    NurseStationItemInfoDetailsVO selectNurseStationItemInfoVO(Long id);

    /**
     * 根据护理项目id查询护理项目信息
     *
     * @param itemId 护理项目id
     * @return 护理项目信息
     */
    NurseStationItem getNurseStationItemById(Long itemId);

    /**
     * 护理项目修改上架状态
     *
     * @param id          项目id
     * @param shelfStatus 上架状态
     * @return int
     */
    int updateShelfStatusById(@Param("id") Long id, @Param("shelfStatus") String shelfStatus);
}